[jboss-cvs] JBossAS SVN: r61155 - branches/tdiesler/trunk/server/src/main/org/jboss/metadata/serviceref.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Tue Mar 6 15:40:55 EST 2007


Author: thomas.diesler at jboss.com
Date: 2007-03-06 15:40:55 -0500 (Tue, 06 Mar 2007)
New Revision: 61155

Modified:
   branches/tdiesler/trunk/server/src/main/org/jboss/metadata/serviceref/ServiceRefHandler.java
Log:
partial commit

Modified: branches/tdiesler/trunk/server/src/main/org/jboss/metadata/serviceref/ServiceRefHandler.java
===================================================================
--- branches/tdiesler/trunk/server/src/main/org/jboss/metadata/serviceref/ServiceRefHandler.java	2007-03-06 20:29:01 UTC (rev 61154)
+++ branches/tdiesler/trunk/server/src/main/org/jboss/metadata/serviceref/ServiceRefHandler.java	2007-03-06 20:40:55 UTC (rev 61155)
@@ -23,15 +23,15 @@
 
 // $Id$
 
-import java.util.Iterator;
+import java.lang.reflect.AnnotatedElement;
 
 import javax.naming.Context;
+import javax.naming.NamingException;
 
-import org.jboss.deployers.spi.DeploymentException;
-import org.jboss.deployers.spi.deployer.DeploymentUnit;
+import org.jboss.virtual.VirtualFile;
 
 /**
  * Implemtent to bind JAXRPC ServiceRefs
  * 
  * @author Thomas.Diesler at jboss.org
  * @since 05-May-2004
@@ -39,12 +39,7 @@
 public interface ServiceRefHandler
 {
    /**
-    * Binds a JAXRPC Service into the callers ENC for every service-ref element
-    *
-    * @param envCtx      ENC to bind the javax.rpc.xml.Service object to
-    * @param serviceRefs An iterator of the service-ref elements in the client deployment descriptor
-    * @param unit  The client's deployment unit
-    * @throws DeploymentException if it goes wrong
+    * Binds a Service into the callers ENC for every service-ref element
     */
-   void bindServiceRefs(Context envCtx, Iterator serviceRefs, DeploymentUnit unit);
+   void setupServiceRef(Context encCtx, String encName, AnnotatedElement anElement, VirtualFile vfsRoot, String xmlFragment) throws NamingException;
 }
@@ -23,15 +23,15 @@
 
 /**
- * Implemtent to bind JAXRPC ServiceRefs
+ * Implemtent to bind web service ref
  * 
  * @author Thomas.Diesler at jboss.org




More information about the jboss-cvs-commits mailing list